Crate mdns_proto

Crate mdns_proto 

mDNS Protocol

This crate provides a no_std sans-I/O implementation of the mDNS protocol.

github LoC Build codecov

docs.rs crates.io crates.io license

MSRV

The Minimum Supported Rust Version (MSRV) for this crate is Rust 1.85. Any change to this MSRV will be accompanied by a minor version bump.

License

Dual licensed under the MIT and Apache 2.0 licenses.

Modules

client
The client endpoint
error
The error type for the mDNS protocol
proto
An implementation of the mDNS protocol
server
The server endpoint

Structs

ConnectionHandle
Internal identifier for a Connection currently associated with an endpoint
Srv
RFC 2782, DNS SRV RR, February 2000
Str
A TXT string segment that refers to either raw bytes or a pre-parsed string
Strings
Iterator over strings in a TXT record
Txt

Traits

Pool
Pre-allocated storage for a uniform data type.