CancelQueryError

Enum CancelQueryError 

#[non_exhaustive]
pub enum CancelQueryError { QueryNotFound(QueryHandle), }
Available on crate features alloc or no-atomic or std only.
Errors raised by query-handle lookups on Endpoint (poll_query_*, handle_query_timeout, cancel_query, …) when the handle no longer corresponds to an active query. A query disappears from the endpoint when its terminal update has been drained via Endpoint::poll_query (auto-prune) or after an explicit Endpoint::cancel_query call.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


QueryNotFound(QueryHandle)

The handle does not refer to a currently registered query.

Implementations

Source

impl CancelQueryError

pub const fn is_query_not_found(&self) -> bool

Returns true if this value is of type QueryNotFound. Returns false otherwise

Source

impl CancelQueryError

pub fn unwrap_query_not_found(self) -> QueryHandle

Unwraps this value to the CancelQueryError::QueryNotFound variant. Panics if this value is of any other type.

pub fn unwrap_query_not_found_ref(&self) -> &QueryHandle

Unwraps this reference to the CancelQueryError::QueryNotFound variant. Panics if this value is of any other type.

Source

impl CancelQueryError

pub fn try_unwrap_query_not_found( self, ) -> Result<QueryHandle, TryUnwrapError<Self>>

Attempts to unwrap this value to the CancelQueryError::QueryNotFound variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_query_not_found_ref( &self, ) -> Result<&QueryHandle, TryUnwrapError<&Self>>

Attempts to unwrap this reference to the CancelQueryError::QueryNotFound variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.