#[non_exhaustive]pub enum HandleTimeoutError {
Overflow,
}Expand description
Errors raised by Service::handle_timeout.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Overflow
A deadline arithmetic operation overflowed.
Implementations
Sourceimpl HandleTimeoutError
impl HandleTimeoutError
Sourcepub const fn is_overflow(&self) -> bool
pub const fn is_overflow(&self) -> bool
Returns true if this value is of type Overflow. Returns false otherwise
Sourceimpl HandleTimeoutError
impl HandleTimeoutError
Sourcepub fn unwrap_overflow(self)
pub fn unwrap_overflow(self)
Unwraps this value to the HandleTimeoutError::Overflow variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_overflow_ref(&self)
pub fn unwrap_overflow_ref(&self)
Unwraps this reference to the HandleTimeoutError::Overflow variant.
Panics if this value is of any other type.
Sourceimpl HandleTimeoutError
impl HandleTimeoutError
Sourcepub fn try_unwrap_overflow(self) -> Result<(), TryUnwrapError<Self>>
pub fn try_unwrap_overflow(self) -> Result<(), TryUnwrapError<Self>>
Attempts to unwrap this value to the HandleTimeoutError::Overflow variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_overflow_ref(&self) -> Result<(), TryUnwrapError<&Self>>
pub fn try_unwrap_overflow_ref(&self) -> Result<(), TryUnwrapError<&Self>>
Attempts to unwrap this reference to the HandleTimeoutError::Overflow variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.