#[non_exhaustive]pub enum ProtoError {
NotEnoughWriteSpace {
tried_to_write: NonZero<usize>,
available: usize,
buffer_type: BufferType,
},
NotEnoughReadBytes {
tried_to_read: NonZero<usize>,
available: usize,
},
Parse {
name: &'static str,
},
NameTooLong(usize),
InvalidUtf8(Utf8Error),
InvalidCode(InvalidCode),
TooManyUrlSegments(usize),
}Expand description
An error that may occur while using the DNS protocol.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotEnoughWriteSpace
We are trying to write to a buffer, but the buffer doesn’t have enough space.
This error can be fixed by increasing the size of the buffer.
Fields

buffer_type: BufferTypeThe type of the buffer that we tried to write to.
NotEnoughReadBytes
We attempted to read from a buffer, but we ran out of room before we could read the entire value.
This error can be fixed by reading more bytes.
Fields
Parse
We tried to parse this value, but it was invalid.
NameTooLong(usize)
We tried to serialize a string longer than 256 bytes.
InvalidUtf8(Utf8Error)
We could not create a valid UTF-8 string from the bytes we read.
InvalidCode(InvalidCode)
We could not convert a raw number to a code.
TooManyUrlSegments(usize)
We do not support this many URL segments.