#[non_exhaustive]pub enum StartQueryError {
StorageFull(StorageFullError),
}Expand description
Errors raised by Endpoint::try_start_query.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
StorageFull(StorageFullError)
The internal routing pool is full.
Implementations
Sourceimpl StartQueryError
impl StartQueryError
Sourcepub const fn is_storage_full(&self) -> bool
pub const fn is_storage_full(&self) -> bool
Returns true if this value is of type StorageFull. Returns false otherwise
Sourceimpl StartQueryError
impl StartQueryError
Sourcepub fn unwrap_storage_full(self) -> StorageFullError
pub fn unwrap_storage_full(self) -> StorageFullError
Unwraps this value to the StartQueryError::StorageFull variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_storage_full_ref(&self) -> &StorageFullError
pub fn unwrap_storage_full_ref(&self) -> &StorageFullError
Unwraps this reference to the StartQueryError::StorageFull variant.
Panics if this value is of any other type.
Sourceimpl StartQueryError
impl StartQueryError
Sourcepub fn try_unwrap_storage_full(
self,
) -> Result<StorageFullError, TryUnwrapError<Self>>
pub fn try_unwrap_storage_full( self, ) -> Result<StorageFullError, TryUnwrapError<Self>>
Attempts to unwrap this value to the StartQueryError::StorageFull variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_storage_full_ref(
&self,
) -> Result<&StorageFullError, TryUnwrapError<&Self>>
pub fn try_unwrap_storage_full_ref( &self, ) -> Result<&StorageFullError, TryUnwrapError<&Self>>
Attempts to unwrap this reference to the StartQueryError::StorageFull variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.