#[non_exhaustive]pub enum TransmitError {
BufferTooSmall(BufferTooSmallDetail),
}Expand description
Errors raised by Service::poll_transmit.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BufferTooSmall(BufferTooSmallDetail)
The caller-supplied buffer is too small to hold the encoded message.
Implementations
Sourceimpl TransmitError
impl TransmitError
Sourcepub const fn is_buffer_too_small(&self) -> bool
pub const fn is_buffer_too_small(&self) -> bool
Returns true if this value is of type BufferTooSmall. Returns false otherwise
Sourceimpl TransmitError
impl TransmitError
Sourcepub fn unwrap_buffer_too_small(self) -> BufferTooSmallDetail
pub fn unwrap_buffer_too_small(self) -> BufferTooSmallDetail
Unwraps this value to the TransmitError::BufferTooSmall variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_buffer_too_small_ref(&self) -> &BufferTooSmallDetail
pub fn unwrap_buffer_too_small_ref(&self) -> &BufferTooSmallDetail
Unwraps this reference to the TransmitError::BufferTooSmall variant.
Panics if this value is of any other type.
Sourceimpl TransmitError
impl TransmitError
Sourcepub fn try_unwrap_buffer_too_small(
self,
) -> Result<BufferTooSmallDetail, TryUnwrapError<Self>>
pub fn try_unwrap_buffer_too_small( self, ) -> Result<BufferTooSmallDetail, TryUnwrapError<Self>>
Attempts to unwrap this value to the TransmitError::BufferTooSmall variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_buffer_too_small_ref(
&self,
) -> Result<&BufferTooSmallDetail, TryUnwrapError<&Self>>
pub fn try_unwrap_buffer_too_small_ref( &self, ) -> Result<&BufferTooSmallDetail, TryUnwrapError<&Self>>
Attempts to unwrap this reference to the TransmitError::BufferTooSmall variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.