QueryEvent

Enum QueryEvent 

#[non_exhaustive]
pub enum QueryEvent<'a> { Answer(Ref<'a>), Truncated, }
Events delivered from Endpoint::handle() to a Query.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Answer(Ref<'a>)

A matching answer record arrived.



Truncated

Query received a truncated response (TC bit). Caller should hold off cancelling this query — more KAS suppression follows.

Implementations

Source

impl<'a> QueryEvent<'a>

pub const fn is_answer(&self) -> bool

Returns true if this value is of type Answer. Returns false otherwise

pub const fn is_truncated(&self) -> bool

Returns true if this value is of type Truncated. Returns false otherwise

Source

impl<'a> QueryEvent<'a>

pub fn unwrap_answer(self) -> Ref<'a>

Unwraps this value to the QueryEvent::Answer variant. Panics if this value is of any other type.

pub fn unwrap_answer_ref(&self) -> &Ref<'a>

Unwraps this reference to the QueryEvent::Answer variant. Panics if this value is of any other type.

pub fn unwrap_truncated(self)

Unwraps this value to the QueryEvent::Truncated variant. Panics if this value is of any other type.

pub fn unwrap_truncated_ref(&self)

Unwraps this reference to the QueryEvent::Truncated variant. Panics if this value is of any other type.

Source

impl<'a> QueryEvent<'a>

pub fn try_unwrap_answer(self) -> Result<Ref<'a>, TryUnwrapError<Self>>

Attempts to unwrap this value to the QueryEvent::Answer variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_answer_ref(&self) -> Result<&Ref<'a>, TryUnwrapError<&Self>>

Attempts to unwrap this reference to the QueryEvent::Answer variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_truncated(self) -> Result<(), TryUnwrapError<Self>>

Attempts to unwrap this value to the QueryEvent::Truncated variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_truncated_ref(&self) -> Result<(), TryUnwrapError<&Self>>

Attempts to unwrap this reference to the QueryEvent::Truncated variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.