#[non_exhaustive]pub enum QueryUpdate {
Timeout,
Done,
}Expand description
App-level events emitted by Query::poll().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Timeout
Query’s retry budget expired without finding a match.
Done
Query is finished (caller cancelled or completed enough answers).
Implementations
Sourceimpl QueryUpdate
impl QueryUpdate
Sourceimpl QueryUpdate
impl QueryUpdate
Sourcepub fn unwrap_timeout(self)
pub fn unwrap_timeout(self)
Unwraps this value to the QueryUpdate::Timeout variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_timeout_ref(&self)
pub fn unwrap_timeout_ref(&self)
Unwraps this reference to the QueryUpdate::Timeout variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_done(self)
pub fn unwrap_done(self)
Unwraps this value to the QueryUpdate::Done variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_done_ref(&self)
pub fn unwrap_done_ref(&self)
Unwraps this reference to the QueryUpdate::Done variant.
Panics if this value is of any other type.
Sourceimpl QueryUpdate
impl QueryUpdate
Sourcepub fn try_unwrap_timeout(self) -> Result<(), TryUnwrapError<Self>>
pub fn try_unwrap_timeout(self) -> Result<(), TryUnwrapError<Self>>
Attempts to unwrap this value to the QueryUpdate::Timeout variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_timeout_ref(&self) -> Result<(), TryUnwrapError<&Self>>
pub fn try_unwrap_timeout_ref(&self) -> Result<(), TryUnwrapError<&Self>>
Attempts to unwrap this reference to the QueryUpdate::Timeout variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_done(self) -> Result<(), TryUnwrapError<Self>>
pub fn try_unwrap_done(self) -> Result<(), TryUnwrapError<Self>>
Attempts to unwrap this value to the QueryUpdate::Done variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_done_ref(&self) -> Result<(), TryUnwrapError<&Self>>
pub fn try_unwrap_done_ref(&self) -> Result<(), TryUnwrapError<&Self>>
Attempts to unwrap this reference to the QueryUpdate::Done variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.