RouteEvent

Enum RouteEvent 

#[non_exhaustive]
pub enum RouteEvent<'a> { ToService(ToService<'a>), ToQuery(ToQuery<'a>), CacheUpdated, }
A routing decision yielded by Endpoint::handle().

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ToService(ToService<'a>)

Route the event to the matched service.



ToQuery(ToQuery<'a>)

Route the event to the matched query.



CacheUpdated

The endpoint cache observed new or refreshed records as a side effect of this datagram. Callers can use this as a hint to re-poll queries.

Implementations

Source

impl<'a> RouteEvent<'a>

pub const fn is_to_service(&self) -> bool

Returns true if this value is of type ToService. Returns false otherwise

pub const fn is_to_query(&self) -> bool

Returns true if this value is of type ToQuery. Returns false otherwise

pub const fn is_cache_updated(&self) -> bool

Returns true if this value is of type CacheUpdated. Returns false otherwise

Source

impl<'a> RouteEvent<'a>

pub fn unwrap_to_service(self) -> ToService<'a>

Unwraps this value to the RouteEvent::ToService variant. Panics if this value is of any other type.

pub fn unwrap_to_service_ref(&self) -> &ToService<'a>

Unwraps this reference to the RouteEvent::ToService variant. Panics if this value is of any other type.

pub fn unwrap_to_query(self) -> ToQuery<'a>

Unwraps this value to the RouteEvent::ToQuery variant. Panics if this value is of any other type.

pub fn unwrap_to_query_ref(&self) -> &ToQuery<'a>

Unwraps this reference to the RouteEvent::ToQuery variant. Panics if this value is of any other type.

pub fn unwrap_cache_updated(self)

Unwraps this value to the RouteEvent::CacheUpdated variant. Panics if this value is of any other type.

pub fn unwrap_cache_updated_ref(&self)

Unwraps this reference to the RouteEvent::CacheUpdated variant. Panics if this value is of any other type.

Source

impl<'a> RouteEvent<'a>

pub fn try_unwrap_to_service( self, ) -> Result<ToService<'a>, TryUnwrapError<Self>>

Attempts to unwrap this value to the RouteEvent::ToService variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_to_service_ref( &self, ) -> Result<&ToService<'a>, TryUnwrapError<&Self>>

Attempts to unwrap this reference to the RouteEvent::ToService variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_to_query(self) -> Result<ToQuery<'a>, TryUnwrapError<Self>>

Attempts to unwrap this value to the RouteEvent::ToQuery variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_to_query_ref( &self, ) -> Result<&ToQuery<'a>, TryUnwrapError<&Self>>

Attempts to unwrap this reference to the RouteEvent::ToQuery variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_cache_updated(self) -> Result<(), TryUnwrapError<Self>>

Attempts to unwrap this value to the RouteEvent::CacheUpdated variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_cache_updated_ref(&self) -> Result<(), TryUnwrapError<&Self>>

Attempts to unwrap this reference to the RouteEvent::CacheUpdated variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.