#[non_exhaustive]pub enum ServiceUpdate {
Established,
Renamed(ServiceRenamed),
Conflict,
HostConflict,
}alloc or heapless or no-atomic or std only.Expand description
App-level events emitted by Service::poll().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Established
Probing completed without conflict; the service is now advertised.
Renamed(ServiceRenamed)
Probing detected a conflict; the service rebranded to a new name.
Conflict
A conflict cannot be resolved automatically (e.g. tiebreak space exhausted). The caller must intervene.
HostConflict
A peer claimed our host name (A/AAAA owner) during probing.
The service does NOT rename itself automatically. The caller must resolve the conflict by choosing a new host name and re-registering, or by deferring to the peer.
Implementations
Sourceimpl ServiceUpdate
impl ServiceUpdate
Sourcepub const fn is_established(&self) -> bool
pub const fn is_established(&self) -> bool
Returns true if this value is of type Established. Returns false otherwise
Sourcepub const fn is_renamed(&self) -> bool
pub const fn is_renamed(&self) -> bool
Returns true if this value is of type Renamed. Returns false otherwise
Sourcepub const fn is_conflict(&self) -> bool
pub const fn is_conflict(&self) -> bool
Returns true if this value is of type Conflict. Returns false otherwise
Sourcepub const fn is_host_conflict(&self) -> bool
pub const fn is_host_conflict(&self) -> bool
Returns true if this value is of type HostConflict. Returns false otherwise
Sourceimpl ServiceUpdate
impl ServiceUpdate
Sourcepub fn unwrap_established(self)
pub fn unwrap_established(self)
Unwraps this value to the ServiceUpdate::Established variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_established_ref(&self)
pub fn unwrap_established_ref(&self)
Unwraps this reference to the ServiceUpdate::Established variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_renamed(self) -> ServiceRenamed
pub fn unwrap_renamed(self) -> ServiceRenamed
Unwraps this value to the ServiceUpdate::Renamed variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_renamed_ref(&self) -> &ServiceRenamed
pub fn unwrap_renamed_ref(&self) -> &ServiceRenamed
Unwraps this reference to the ServiceUpdate::Renamed variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_conflict(self)
pub fn unwrap_conflict(self)
Unwraps this value to the ServiceUpdate::Conflict variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_conflict_ref(&self)
pub fn unwrap_conflict_ref(&self)
Unwraps this reference to the ServiceUpdate::Conflict variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_host_conflict(self)
pub fn unwrap_host_conflict(self)
Unwraps this value to the ServiceUpdate::HostConflict variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_host_conflict_ref(&self)
pub fn unwrap_host_conflict_ref(&self)
Unwraps this reference to the ServiceUpdate::HostConflict variant.
Panics if this value is of any other type.
Sourceimpl ServiceUpdate
impl ServiceUpdate
Sourcepub fn try_unwrap_established(self) -> Result<(), TryUnwrapError<Self>>
pub fn try_unwrap_established(self) -> Result<(), TryUnwrapError<Self>>
Attempts to unwrap this value to the ServiceUpdate::Established variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_established_ref(&self) -> Result<(), TryUnwrapError<&Self>>
pub fn try_unwrap_established_ref(&self) -> Result<(), TryUnwrapError<&Self>>
Attempts to unwrap this reference to the ServiceUpdate::Established variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_renamed(self) -> Result<ServiceRenamed, TryUnwrapError<Self>>
pub fn try_unwrap_renamed(self) -> Result<ServiceRenamed, TryUnwrapError<Self>>
Attempts to unwrap this value to the ServiceUpdate::Renamed variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_renamed_ref(
&self,
) -> Result<&ServiceRenamed, TryUnwrapError<&Self>>
pub fn try_unwrap_renamed_ref( &self, ) -> Result<&ServiceRenamed, TryUnwrapError<&Self>>
Attempts to unwrap this reference to the ServiceUpdate::Renamed variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_conflict(self) -> Result<(), TryUnwrapError<Self>>
pub fn try_unwrap_conflict(self) -> Result<(), TryUnwrapError<Self>>
Attempts to unwrap this value to the ServiceUpdate::Conflict variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_conflict_ref(&self) -> Result<(), TryUnwrapError<&Self>>
pub fn try_unwrap_conflict_ref(&self) -> Result<(), TryUnwrapError<&Self>>
Attempts to unwrap this reference to the ServiceUpdate::Conflict variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_host_conflict(self) -> Result<(), TryUnwrapError<Self>>
pub fn try_unwrap_host_conflict(self) -> Result<(), TryUnwrapError<Self>>
Attempts to unwrap this value to the ServiceUpdate::HostConflict variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_host_conflict_ref(&self) -> Result<(), TryUnwrapError<&Self>>
pub fn try_unwrap_host_conflict_ref(&self) -> Result<(), TryUnwrapError<&Self>>
Attempts to unwrap this reference to the ServiceUpdate::HostConflict variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.