pub struct ToQuery<'a> { /* private fields */ }Expand description
A routing decision produced by Endpoint::handle().
Implementations
Sourceimpl<'a> ToQuery<'a>
impl<'a> ToQuery<'a>
Sourcepub const fn handle(&self) -> QueryHandle
pub const fn handle(&self) -> QueryHandle
Returns the query handle this event is addressed to.
Sourcepub const fn event(&self) -> &QueryEvent<'a>
pub const fn event(&self) -> &QueryEvent<'a>
Returns a reference to the query event payload.
Sourcepub const fn into_event(self) -> QueryEvent<'a>
pub const fn into_event(self) -> QueryEvent<'a>
Consumes the routing decision and returns the inner event.