pub struct ToService<'a> { /* private fields */ }Expand description
A routing decision produced by Endpoint::handle().
Implementations
Sourceimpl<'a> ToService<'a>
impl<'a> ToService<'a>
Sourcepub const fn handle(&self) -> ServiceHandle
pub const fn handle(&self) -> ServiceHandle
Returns the service handle this event is addressed to.
Sourcepub const fn event(&self) -> &ServiceEvent<'a>
pub const fn event(&self) -> &ServiceEvent<'a>
Returns a reference to the service event payload.
Sourcepub const fn into_event(self) -> ServiceEvent<'a>
pub const fn into_event(self) -> ServiceEvent<'a>
Consumes the routing decision and returns the inner event.