#[non_exhaustive]#[repr(u16)]pub enum ResourceType {
Show 89 variants
A = 1,
NS = 2,
MD = 3,
MF = 4,
CName = 5,
Soa = 6,
MB = 7,
MG = 8,
MR = 9,
Null = 10,
Wks = 11,
Ptr = 12,
HInfo = 13,
MInfo = 14,
MX = 15,
Txt = 16,
RP = 17,
AfsDb = 18,
X25 = 19,
Isdn = 20,
Rt = 21,
NSap = 22,
NSapPtr = 23,
Sig = 24,
Key = 25,
Px = 26,
GPos = 27,
AAAA = 28,
Loc = 29,
Nxt = 30,
EId = 31,
NimLoc = 32,
Srv = 33,
AtmA = 34,
NAPtr = 35,
Kx = 36,
Cert = 37,
A6 = 38,
DName = 39,
Sink = 40,
Opt = 41,
ApL = 42,
DS = 43,
SshFp = 44,
IpSecKey = 45,
RRSig = 46,
NSEC = 47,
DNSKey = 48,
DHCID = 49,
NSEC3 = 50,
NSEC3Param = 51,
TLSA = 52,
SMimeA = 53,
HIP = 55,
NInfo = 56,
RKey = 57,
TALink = 58,
CDS = 59,
CDNSKey = 60,
OpenPGPKey = 61,
CSync = 62,
ZoneMD = 63,
Svcb = 64,
Https = 65,
Spf = 99,
UInfo = 100,
UID = 101,
GID = 102,
Unspec = 103,
NID = 104,
L32 = 105,
L64 = 106,
LP = 107,
EUI48 = 108,
EUI64 = 109,
TKey = 249,
TSig = 250,
Ixfr = 251,
Axfr = 252,
MailB = 253,
MailA = 254,
Wildcard = 255,
Uri = 256,
Caa = 257,
Avc = 258,
Doa = 259,
Amtrelay = 260,
TA = 32_768,
DLV = 32_769,
}Expand description
The resource types that a question can ask for.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
A = 1
Get the host’s IPv4 address.
NS = 2
Get the authoritative name servers for a domain.
MD = 3
Get the mail server for a domain.
MF = 4
Get the mail forwarder for a domain.
CName = 5
Get the canonical name for a domain.
Soa = 6
Get the start of authority record for a domain.
MB = 7
Get the mailbox for a domain.
MG = 8
Get the mail group member for a domain.
MR = 9
Get the mail rename domain for a domain.
Null = 10
Get the null record for a domain.
Wks = 11
Get the well known services for a domain.
Ptr = 12
Get the domain pointer for a domain.
HInfo = 13
Get the host information for a domain.
MInfo = 14
Get the mailbox or mail list information for a domain.
MX = 15
Get the mail exchange for a domain.
Txt = 16
Get the text for a domain.
RP = 17
Get the responsible person for a domain.
AfsDb = 18
Get the AFS database location for a domain.
X25 = 19
Get the X.25 address for a domain.
Isdn = 20
Get the ISDN address for a domain.
Rt = 21
Get the router for a domain.
NSap = 22
Get the NSAP address for a domain.
NSapPtr = 23
Get the reverse NSAP address for a domain.
Sig = 24
Get the security signature for a domain.
Key = 25
Get the key for a domain.
Px = 26
Get the X.400 mail mapping for a domain.
GPos = 27
Get the geographical location for a domain.
AAAA = 28
Get the IPv6 address for a domain.
Loc = 29
Get the location for a domain.
Nxt = 30
Get the next domain name in a zone.
EId = 31
Get the endpoint identifier for a domain.
NimLoc = 32
Get the Nimrod locator for a domain.
Srv = 33
Get the server selection for a domain.
AtmA = 34
Get the ATM address for a domain.
NAPtr = 35
Get the naming authority pointer for a domain.
Kx = 36
Get the key exchange for a domain.
Cert = 37
Get the certificate for a domain.
A6 = 38
Get the IPv6 address for a domain.
This is obsolete; use AAAA instead.
DName = 39
Get the DNAME for a domain.
Sink = 40
Get the sink for a domain.
Opt = 41
Get the OPT for a domain.
ApL = 42
Get the address prefix list for a domain.
DS = 43
Get the delegation signer for a domain.
SshFp = 44
Get the SSH key fingerprint for a domain.
IpSecKey = 45
Get the IPSEC key for a domain.
RRSig = 46
Get the resource record signature for a domain.
NSEC = 47
Get the next secure record for a domain.
DNSKey = 48
Get the DNSKEY for a domain.
DHCID = 49
Get the DHCID for a domain.
NSEC3 = 50
Get the NSEC3 for a domain.
NSEC3Param = 51
Get the NSEC3 parameters for a domain.
TLSA = 52
Get the TLSA for a domain.
SMimeA = 53
Get the S/MIME certificate association for a domain.
HIP = 55
Get the host information for a domain.
NInfo = 56
Get the NINFO for a domain.
RKey = 57
Get the RKEY for a domain.
TALink = 58
Get the trust anchor link for a domain.
CDS = 59
Get the child DS for a domain.
CDNSKey = 60
Get the DNSKEY for a domain.
OpenPGPKey = 61
Get the OpenPGP key for a domain.
CSync = 62
Get the Child-to-Parent Synchronization for a domain.
ZoneMD = 63
Get the Zone Data Message for a domain.
Svcb = 64
Get the General Purpose Service Binding for a domain.
Https = 65
Get the HTTP Service Binding for a domain.
Spf = 99
Get the Sender Policy Framework for a domain.
UInfo = 100
Get the UINFO for a domain.
UID = 101
Get the UID for a domain.
GID = 102
Get the GID for a domain.
Unspec = 103
Get the UNSPEC for a domain.
NID = 104
Get the NID for a domain.
L32 = 105
Get the L32 for a domain.
L64 = 106
Get the L64 for a domain.
LP = 107
Get the LP for a domain.
EUI48 = 108
Get the EUI48 for a domain.
EUI64 = 109
Get the EUI64 for a domain.
TKey = 249
Get the transaction key for a domain.
TSig = 250
Get the transaction signature for a domain.
Ixfr = 251
Get the incremental transfer for a domain.
Axfr = 252
Get the transfer of an entire zone for a domain.
MailB = 253
Get the mailbox-related records for a domain.
MailA = 254
Get the mail agent RRs for a domain.
This is obsolete; use MX instead.
Wildcard = 255
Get the wildcard match for a domain.
Uri = 256
Get the URI for a domain.
Caa = 257
Get the certification authority authorization for a domain.
Avc = 258
Get the application visibility and control for a domain.
Doa = 259
Get the digital object architecture for a domain.
Amtrelay = 260
Get the automatic network discovery for a domain.
TA = 32_768
Get the DNSSEC trust authorities for a domain.
DLV = 32_769
Get the DNSSEC lookaside validation for a domain.