#[non_exhaustive]#[repr(u16)]pub enum ResponseCode {
Show 20 variants
NoError = 0,
FormatError = 1,
ServerFailure = 2,
NameError = 3,
NotImplemented = 4,
Refused = 5,
YxDomain = 6,
YxRrSet = 7,
NxRrSet = 8,
NotAuth = 9,
NotZone = 10,
DsoTypeNi = 11,
BadVers = 16,
BadKey = 17,
BadTime = 18,
BadMode = 19,
BadName = 20,
BadAlg = 21,
BadTrunc = 22,
BadCookie = 23,
}Expand description
The response code for a query.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoError = 0
There was no error in the query.
FormatError = 1
The query was malformed.
ServerFailure = 2
The server failed to fulfill the query.
NameError = 3
The name does not exist.
NotImplemented = 4
The query is not implemented.
Refused = 5
The query is refused.
YxDomain = 6
The name exists, but the query type is not supported.
YxRrSet = 7
The name does not exist, but the query type is supported.
NxRrSet = 8
The name exists, but the query type is not supported.
NotAuth = 9
The server is not authoritative for the zone.
NotZone = 10
The name does not exist in the zone.
DsoTypeNi = 11
The DSO-TYPE is not supported.
BadVers = 16
Bad OPT version.
BadKey = 17
Key not recognized.
BadTime = 18
Signature out of time window.
BadMode = 19
Bad TKEY mode.
BadName = 20
Duplicate key name.
BadAlg = 21
Algorithm not supported.
BadTrunc = 22
Bad truncation.
BadCookie = 23
Bad/missing server cookie.