pub enum Error<S, Q> {
Connection(S),
Query(Q),
ConnectionNotFound(ConnectionHandle),
QueryNotFound(QueryHandle),
InvalidOpcode(Opcode),
InvalidResponseCode(ResponseCode),
TrancatedQuery,
Proto(ProtoError),
}Expand description
The error type for the server.
Variants
Connection(S)
The server is full and cannot hold any more connections.
Query(Q)
The connection is full and cannot hold any more queries.
ConnectionNotFound(ConnectionHandle)
The connection is not found.
QueryNotFound(QueryHandle)
The query is not found.
InvalidOpcode(Opcode)
Returned when the a query has an invalid opcode.
InvalidResponseCode(ResponseCode)
Returned when the a query has an invalid response code.
TrancatedQuery
Returned when a query with a high truncated bit is received.
Proto(ProtoError)
Protocol error