QueryHandle

Struct QueryHandle 

pub struct QueryHandle { /* private fields */ }
Internal identifier for a Connection currently associated with an endpoint

Implementations

Source

impl QueryHandle

pub const fn message_id(&self) -> u16

Returns the message id associated with the query handle.

pub const fn query_id(&self) -> usize

Returns the query id associated with the query handle.

pub const fn connection_id(&self) -> usize

Returns the connection id associated with the query handle.