HandleError

Enum HandleError 

#[non_exhaustive]
pub enum HandleError { Parse(ParseError), InvalidOpcode(Opcode), InvalidResponseCode(ResponseCode), }
Errors raised by Endpoint::handle.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Parse(ParseError)

The datagram could not be parsed.



InvalidOpcode(Opcode)

The incoming opcode is not Query (mDNS only supports Query).



InvalidResponseCode(ResponseCode)

The incoming response code is not NoError (mDNS requires NoError).

Implementations

Source

impl HandleError

pub const fn is_parse(&self) -> bool

Returns true if this value is of type Parse. Returns false otherwise

pub const fn is_invalid_opcode(&self) -> bool

Returns true if this value is of type InvalidOpcode. Returns false otherwise

pub const fn is_invalid_response_code(&self) -> bool

Returns true if this value is of type InvalidResponseCode. Returns false otherwise

Source

impl HandleError

pub fn unwrap_parse(self) -> ParseError

Unwraps this value to the HandleError::Parse variant. Panics if this value is of any other type.

pub fn unwrap_parse_ref(&self) -> &ParseError

Unwraps this reference to the HandleError::Parse variant. Panics if this value is of any other type.

pub fn unwrap_invalid_opcode(self) -> Opcode

Unwraps this value to the HandleError::InvalidOpcode variant. Panics if this value is of any other type.

pub fn unwrap_invalid_opcode_ref(&self) -> &Opcode

Unwraps this reference to the HandleError::InvalidOpcode variant. Panics if this value is of any other type.

pub fn unwrap_invalid_response_code(self) -> ResponseCode

Unwraps this value to the HandleError::InvalidResponseCode variant. Panics if this value is of any other type.

pub fn unwrap_invalid_response_code_ref(&self) -> &ResponseCode

Unwraps this reference to the HandleError::InvalidResponseCode variant. Panics if this value is of any other type.

Source

impl HandleError

pub fn try_unwrap_parse(self) -> Result<ParseError, TryUnwrapError<Self>>

Attempts to unwrap this value to the HandleError::Parse variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_parse_ref(&self) -> Result<&ParseError, TryUnwrapError<&Self>>

Attempts to unwrap this reference to the HandleError::Parse variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_invalid_opcode(self) -> Result<Opcode, TryUnwrapError<Self>>

Attempts to unwrap this value to the HandleError::InvalidOpcode variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_invalid_opcode_ref( &self, ) -> Result<&Opcode, TryUnwrapError<&Self>>

Attempts to unwrap this reference to the HandleError::InvalidOpcode variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_invalid_response_code( self, ) -> Result<ResponseCode, TryUnwrapError<Self>>

Attempts to unwrap this value to the HandleError::InvalidResponseCode variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_invalid_response_code_ref( &self, ) -> Result<&ResponseCode, TryUnwrapError<&Self>>

Attempts to unwrap this reference to the HandleError::InvalidResponseCode variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.