ToService

Struct ToService 

pub struct ToService<'a> { /* private fields */ }
A routing decision produced by Endpoint::handle().

Implementations

Source

impl<'a> ToService<'a>

pub const fn handle(&self) -> ServiceHandle

Returns the service handle this event is addressed to.

pub const fn event(&self) -> &ServiceEvent<'a>

Returns a reference to the service event payload.

pub const fn into_event(self) -> ServiceEvent<'a>

Consumes the routing decision and returns the inner event.