pub struct Message<'arrays, 'innards> { /* private fields */ }Expand description
The message for a DNS query.
Implementations
Sourceimpl<'arrays, 'innards> Message<'arrays, 'innards>
impl<'arrays, 'innards> Message<'arrays, 'innards>
Sourcepub fn new(
id: u16,
flags: Flags,
questions: &'arrays mut [Question<'innards>],
answers: &'arrays mut [ResourceRecord<'innards>],
authorities: &'arrays mut [ResourceRecord<'innards>],
additional: &'arrays mut [ResourceRecord<'innards>],
) -> Message<'arrays, 'innards>
pub fn new( id: u16, flags: Flags, questions: &'arrays mut [Question<'innards>], answers: &'arrays mut [ResourceRecord<'innards>], authorities: &'arrays mut [ResourceRecord<'innards>], additional: &'arrays mut [ResourceRecord<'innards>], ) -> Message<'arrays, 'innards>
Create a new message from a set of buffers for each section.
Panics
This function panics if the number of questions, answers, authorities, or additional records
is greater than u16::MAX.
Sourcepub fn flags_mut(&mut self) -> &mut Flags
pub fn flags_mut(&mut self) -> &mut Flags
Get a mutable reference to the flags for this message.
Sourcepub fn questions_mut(&mut self) -> &mut [Question<'innards>]
pub fn questions_mut(&mut self) -> &mut [Question<'innards>]
Get a mutable reference to the questions in this message.
Sourcepub fn answers(&self) -> &[ResourceRecord<'innards>]
pub fn answers(&self) -> &[ResourceRecord<'innards>]
Get the answers in this message.
Sourcepub fn answers_mut(&mut self) -> &mut [ResourceRecord<'innards>]
pub fn answers_mut(&mut self) -> &mut [ResourceRecord<'innards>]
Get a mutable reference to the answers in this message.
Get the authorities in this message.
Get a mutable reference to the authorities in this message.
Sourcepub fn additional(&self) -> &[ResourceRecord<'innards>]
pub fn additional(&self) -> &[ResourceRecord<'innards>]
Get the additional records in this message.
Sourcepub fn additional_mut(&mut self) -> &mut [ResourceRecord<'innards>]
pub fn additional_mut(&mut self) -> &mut [ResourceRecord<'innards>]
Get a mutable reference to the additional records in this message.
Sourcepub fn space_needed(&self) -> usize
pub fn space_needed(&self) -> usize
Get the buffer space needed to serialize this message.
Sourcepub fn write(&self, buffer: &mut [u8]) -> Result<usize, Error>
pub fn write(&self, buffer: &mut [u8]) -> Result<usize, Error>
Write this message to a buffer.
Returns the number of bytes written.
Errors
This function may raise Error::NameTooLong if a Label is too long to be serialized.
Panics
This function panics if the buffer is not large enough to hold the serialized message. This
panic can be avoided by ensuring the buffer contains at least [space_needed] bytes.
Sourcepub fn read(
buffer: &'innards [u8],
questions: &'arrays mut [Question<'innards>],
answers: &'arrays mut [ResourceRecord<'innards>],
authorities: &'arrays mut [ResourceRecord<'innards>],
additional: &'arrays mut [ResourceRecord<'innards>],
) -> Result<Message<'arrays, 'innards>, Error>
pub fn read( buffer: &'innards [u8], questions: &'arrays mut [Question<'innards>], answers: &'arrays mut [ResourceRecord<'innards>], authorities: &'arrays mut [ResourceRecord<'innards>], additional: &'arrays mut [ResourceRecord<'innards>], ) -> Result<Message<'arrays, 'innards>, Error>
Read a message from a buffer.
Errors
This function may raise one of the following errors:
Error::NotEnoughReadBytesif the buffer is not large enough to hold the entire structure. You may need to read more data before calling this function again.Error::NotEnoughWriteSpaceif the buffers provided are not large enough to hold the entire structure. You may need to allocate larger buffers before calling this function.Error::InvalidUtf8if a domain name contains invalid UTF-8.Error::NameTooLongif a domain name is too long to be deserialized.Error::InvalidCodeif a domain name contains an invalid label code.