pub struct QueryHandle { /* private fields */ }Expand description
Internal identifier for a Connection currently associated with an endpoint
Implementations
Sourceimpl QueryHandle
impl QueryHandle
Sourcepub const fn message_id(&self) -> u16
pub const fn message_id(&self) -> u16
Returns the message id associated with the query handle.
Sourcepub const fn connection_id(&self) -> usize
pub const fn connection_id(&self) -> usize
Returns the connection id associated with the query handle.